Welcome to Quest's documentation!
=================================

Quest is a python library that provides an API to search for and download data (both geographical and non-geographical) across multiple data sources including both local repositories and web based services. It also provides tools to manipulate and manage that data.

.. toctree::
   :caption: Table of Contents
   :maxdepth: 2

   install
   quickstart
   core_concepts
   api
   developers/index

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`

